package com.bignerdranch.android.geoquiz;

import android.animation.Animator;
import android.animation.AnimatorListenerAdapter;
import android.content.Context;
import android.content.Intent;
import android.os.Build;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.view.View;
import android.view.ViewAnimationUtils;
import android.widget.Button;
import android.widget.TextView;

public class CheatActivity extends AppCompatActivity {

    public static final String EXTRA_ANSWER_IS_TRUE = "com.bignerdranch.android.geoquiz.answer_is_true";
    public static final String EXTRA_ANSWER_SHOWN = "com.bignerdranch.android.geoquiz.answer_shown";
    public static final String EXTRA_CHEATS_REMAINING = "com.bignerdranch.android.geoquiz.cheats_remaining";

    private TextView mAnswerTextView;
    private Button mShowAnswerButton;

    private boolean isAnswerShown;
    private int startCheatsRemaining;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_cheat);

        startCheatsRemaining = getIntent().getIntExtra(EXTRA_CHEATS_REMAINING, 0);

        mAnswerTextView = (TextView) findViewById(R.id.answer_text_view);

        mShowAnswerButton = (Button) findViewById(R.id.show_answer_button);
        mShowAnswerButton.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                showAnswer();
                setResult(true, startCheatsRemaining - 1);

                if(Build.VERSION.SDK_INT >= Build.VERSION_CODES.LOLLIPOP) {
                    int cx = mShowAnswerButton.getWidth() / 2;
                    int cy = mShowAnswerButton.getHeight() / 2;
                    float radius = mShowAnswerButton.getWidth();
                    Animator anim = ViewAnimationUtils.createCircularReveal(mShowAnswerButton, cx, cy, radius, 0);
                    anim.addListener(new AnimatorListenerAdapter() {
                        @Override
                        public void onAnimationEnd(Animator animation) {
                            super.onAnimationEnd(animation);
                            mShowAnswerButton.setVisibility(View.INVISIBLE);
                        }
                    });
                    anim.start();
                } else {
                    mShowAnswerButton.setVisibility(View.INVISIBLE);
                }
            }
        });

        TextView mBuildVersionTextView = findViewById(R.id.version_text_view);
        mBuildVersionTextView.setText(getString(R.string.API_level, Build.VERSION.SDK_INT));

        if(savedInstanceState != null) {
            isAnswerShown = savedInstanceState.getBoolean(EXTRA_ANSWER_SHOWN);
            startCheatsRemaining = savedInstanceState.getInt(EXTRA_CHEATS_REMAINING);

            if(isAnswerShown) {
                showAnswer();
                setResult(isAnswerShown, startCheatsRemaining - 1);
            } else {
                setResult(isAnswerShown, startCheatsRemaining);
            }
        }
    }

    private void showAnswer() {
        if(getIntent().getBooleanExtra(EXTRA_ANSWER_IS_TRUE ,false)) {
            mAnswerTextView.setText(R.string.true_button);
        } else {
            mAnswerTextView.setText(R.string.false_button);
        }
    }

    private void setResult(boolean isAnswerShown, int cheatsRemaining) {
        this.isAnswerShown = isAnswerShown;

        Intent data = new Intent();
        data.putExtra(EXTRA_ANSWER_SHOWN, isAnswerShown);
        data.putExtra(EXTRA_CHEATS_REMAINING, cheatsRemaining);
        setResult(RESULT_OK, data);
    }

    @Override
    public void onSaveInstanceState(Bundle savedInstanceState) {
        super.onSaveInstanceState(savedInstanceState);
        savedInstanceState.putBoolean(EXTRA_ANSWER_SHOWN, isAnswerShown);
        savedInstanceState.putInt(EXTRA_CHEATS_REMAINING, startCheatsRemaining);
    }
}
